@@ -8,6 +8,7 @@ from .commands import (
     continue_update,
     rollback,
     info,
+    show_resources,
     parameters,
     resolve,
     show_table,
@@ -51,6 +52,13 @@ def get_update_parser(subparser, parents=[]):
     parser.add_argument(
         "-n", "--nochangeset", help="No ChangeSet", required=False, action="store_true"
     )
+    parser.add_argument(
+        "-C",
+        "--changeset-original",
+        help="Do not simply ChangeSet",
+        required=False,
+        action="store_true",
+    )
     parser.add_argument("--dryrun", help="Show changeset and exit", action="store_true")
     parser.add_argument(
         "-T", "--showtags", help="Show tags changes in changeset", action="store_true"
@@ -517,6 +525,24 @@ def get_parser():
     )
     parser_info.set_defaults(func=info)
 
+    # resources parser
+    parser_resources = command_subparser.add_parser(
+        "resources", parents=[stack_selection_parser], help="Show Stack Resources"
+    )
+    parser_resources.add_argument(
+        "-F",
+        "--fields",
+        nargs="+",
+        type=str,
+        default=cfg.SHOW_RESOURCES_FIELDS,
+        help="LogicalResourceId PhysicalResourceId ResourceType LastUpdatedTimestamp ResourceStatus ResourceStatusReason",
+    )
+    parser_resources.add_argument("--resource-types", type=str, nargs="+", default=[])
+    parser_resources.add_argument(
+        "-O", "--output", type=str, default="text", choices=["text", "html", "bare"]
+    )
+    parser_resources.set_defaults(func=show_resources)
+
     # parameters parser
     parser_parameters = command_subparser.add_parser(
         "parameters",
